@@ -32,5 +32,11 @@ printTextProtocol(tests)
 
 ## Return success or failure to R CMD CHECK
 if (getErrors(tests)$nFail > 0) {
-    stop("TEST FAILED!")
+   stop("TEST FAILED!")
+}
+if (getErrors(tests)$nErr > 0) {
+   stop("TEST HAD ERRORS!")
+}
+if (getErrors(tests)$nTestFunc < 1) {
+   stop("NO TEST FUNCTIONS RUN!")
 }
